@@ -78,10 +78,15 @@ def get_distro_name():
     os_name = None
     try:
         import platform
-        os_name = platform.dist()[0]
     except ImportError:
         os_name = None
 
+    try:
+        os_name = platform.dist()[0]
+    except AttributeError:
+        import distro
+        os_name = distro.linux_distribution()[0]
+
     if not os_name:
         name = os.popen('lsb_release -i | cut -f 2')
         os_name = name.read().strip()
@@ -140,7 +145,11 @@ class Password(object):
                 self.__authType = AUTH_TYPES[distro_name]
                 if distro_name == 'fedora':
                     import platform
-                    ver = int(platform.dist()[1])
+                    try:
+                       ver = int(platform.dist()[1])
+                    except AttributeError:
+                       import distro
+                       ver = int(distro.linux_distribution()[1])
                     if ver >= 28:
                        self.__authType = AUTH_TYPES['fedora28']
             except KeyError:
@@ -188,7 +197,7 @@ class Password(object):
 
         return password
 
-    def __password_check(self, cmd, timeout=1):
+    def __password_check(self, cmd, timeout=10):
         import io
         output = io.StringIO()
         ok, ret = False, ''
