@@ -1,7 +1,7 @@
 /*****************************************************************************\
     hpijs.cpp : HP Inkjet Server
 
-    Copyright (c) 2001 - 2008, Hewlett-Packard Co.
+    Copyright (c) 2001 - 2008, HP Co.
     All rights reserved.
 
     Redistribution and use in source and binary forms, with or without
@@ -97,7 +97,7 @@ void setLogLevel(UXServices *pSS, char*user_name)
 
     if (pSS->m_iLogLevel & SAVE_PCL_FILE)
     {
-        char    szFileName[64];
+        char    szFileName[MAX_FILE_PATH_LEN];
         snprintf (szFileName,sizeof(szFileName), "%s/hp_%s_ijs_%d_XXXXXX", CUPS_TMP_DIR, user_name,  getpid());
         createTempFile(szFileName, &pSS->outfp);
 
@@ -597,8 +597,8 @@ int main (int argc, char *argv[], char *evenp[])
       const char *arg = argv[1];
       if ((arg[0] == '-') && (arg[1] == 'h'))
       {
-         fprintf(stdout, "\nHewlett-Packard Co. Inkjet Server %s\n", VERSION);
-         fprintf(stdout, "Copyright (c) 2001-2004, Hewlett-Packard Co.\n");
+         fprintf(stdout, "\nHP Co. Inkjet Server %s\n", VERSION);
+         fprintf(stdout, "Copyright (c) 2001-2004, HP Co.\n");
          exit(0);
       }
    }
@@ -632,7 +632,7 @@ int main (int argc, char *argv[], char *evenp[])
    setLogLevel(pSS, user_name);
 
 #ifdef CAPTURE
-   char szCapOutFile[64];
+   char szCapOutFile[MAX_FILE_PATH_LEN];
    snprintf(szCapOutFile, sizeof(szCapOutFile),"%s/hp_%s_ijs_capout_XXXXXX",CUPS_TMP_DIR, user_name);
    if ((pSS->InitScript(szCapOutFile, TRUE)) != NO_ERROR)
       BUG("unable to init capture");
