@@ -303,10 +303,10 @@ static int DevDiscovery(int localOnly)
         GetUriLine(tail, uri, &tail);
         total += AddDevice(uri);
     }
-
+    memset(message, 0, sizeof(message));
     /* Look for Network Scan devices if localonly flag if FALSE. */
     if (!localOnly)
-    {
+    {   
         /* Look for all-in-one scan devices for which print queue created */
         cnt = GetCupsPrinters(&cups_printer);
         for (i=0; i<cnt; i++)
